Module entity

Module entity 

The base of the DDS entity hierarchy.

Most DDS objects (Participant, Topic, Reader, Writer, and others) are entities. See the implementors of Entity for the full list. This module provides the Entity trait with the common methods available to all entities.

Structs

EntityId
A raw entity ID for an entity.
InstanceHandle
A unique opaque handle identifying an instance.

Traits

Entity
Common interface implemented by all members of the DDS entity hierarchy.