#[non_exhaustive]pub enum Error {
Show 13 variants
NonSpecific,
Unsupported,
BadParameter,
PreconditionNotMet,
OutOfResources,
NotEnabled,
ImmutablePolicy,
InconsistentPolicy,
AlreadyDeleted,
Timeout,
NoData,
IllegalOperation,
NotAllowedBySecurity,
}Expand description
Errors that can occur during DDS operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonSpecific
Non specific error.
Unsupported
Feature unsupported.
BadParameter
Bad parameter value.
PreconditionNotMet
Precondition for operation not met.
OutOfResources
When an operation fails because of a lack of resources.
NotEnabled
When a configurable feature is not enabled.
ImmutablePolicy
When an attempt is made to modify an immutable policy.
InconsistentPolicy
When a policy is used with inconsistent values.
AlreadyDeleted
When an attempt is made to delete something more than once.
Timeout
When a timeout has occurred.
NoData
When expected data is not provided.
IllegalOperation
When a function is called when it should not be.
NotAllowedBySecurity
When credentials are insufficient to use the function.