TopicListener

Struct TopicListener 

pub struct TopicListener<T>
where T: Topicable,
{ /* private fields */ }
Listener attached to a Topic<T>.

Implementations

Source

impl<T> TopicListener<T>
where T: Topicable,

pub fn new() -> Self

Creates a new TopicListener<T> with no callbacks registered.

Examples
use cyclonedds::TopicListener;

let listener = TopicListener::<Data>::new();
pub fn with_inconsistent_topic( self, callback: fn(&Topic<'_, '_, T>, InconsistentTopic), ) -> Self

Sets a callback for the InconsistentTopic status event.

The callback receives an InconsistentTopic metadata struct.

Fired when a remote topic is discovered with the same name but an incompatible type or QoS.

Examples
use cyclonedds::listener::TopicListener;

let listener =
    TopicListener::<Data>::new().with_inconsistent_topic(|topic, inconsistent_topic| {
        println!("inconsistent topic: {inconsistent_topic:?}");
    });