This module holds the sample state masks that provide information on the state of a sample in the sample info from a read or take call.
This module holds the sample state masks that provide information on the state of a sample in the sample info from a read or take call.