pub enum SampleRejectedReason {
NotRejected,
RejectedByInstancesLimit,
RejectedBySamplesLimit,
RejectedBySamplesPerInstanceLimit,
}Expand description
Delivered to the
with_sample_rejected
callback when an incoming sample is rejected due to resource limits.
Variants
NotRejected
The sample was not rejected.
RejectedByInstancesLimit
Rejected because the maximum number of instances has been reached.
RejectedBySamplesLimit
Rejected because the maximum number of samples has been reached.
RejectedBySamplesPerInstanceLimit
Rejected because the maximum number of samples per instance has been reached.