pub struct Counter {
pub count: u32,
pub delta: i32,
}Expand description
A cumulative status event counter with a per-notification delta.
Appears in status types to report both the running total of an event and how many times it occurred since the last time the status was read or taken.
Fields
count: u32Total number of times the event has occurred.
delta: i32Change in count since the status was last read or taken.