pub struct LivelinessChanged {
pub alive: Counter,
pub not_alive: Counter,
pub last_publication_handle: InstanceHandle,
}Expand description
Delivered to the
with_liveliness_changed
callback when a matched writer transitions between active and inactive.
Fields
alive: CounterRunning count of matched writers that are currently active.
not_alive: CounterRunning count of matched writers that are currently inactive.
last_publication_handle: InstanceHandleInstance handle of the last writer whose liveliness changed.