pub struct SubscriptionMatched {
pub total: Counter,
pub current: Counter,
pub last_publication_handle: InstanceHandle,
}Expand description
Delivered to the
with_subscription_matched
callback when a writer matching this reader’s topic and QoS
is discovered.
Fields
total: CounterRunning count of writer matches over the lifetime of the reader.
current: CounterCurrent number of matched writers.
last_publication_handle: InstanceHandleInstance handle of the last writer that matched or unmatched.