GuardCondition

Struct GuardCondition 

pub struct GuardCondition<'owner> { /* private fields */ }
A manually triggered condition for use with a WaitSet.

A GuardCondition allows application code to unblock a waiting WaitSet from another thread or in response to an external event. Set it to true to trigger attached waitsets and false to reset it.

Implementations

Source

impl<'o> GuardCondition<'o>

pub fn new(owner: &'o dyn Entity) -> Result<Self>

Creates a new GuardCondition owned by owner.

The guard condition is valid for the lifetime of owner.

Errors

Returns an Error if the guard condition fails to create.

Examples
use cyclonedds::GuardCondition;

let guard_condition = GuardCondition::new(&participant)?;
pub fn set(&mut self, triggered: bool) -> Result<()>

Sets the triggered state of this guard condition.

Setting to true unblocks any WaitSet this condition is attached to. Setting to false resets it.

Errors

Returns an Error if the condition failed to set.

Examples
use cyclonedds::GuardCondition;

let mut guard_condition = GuardCondition::new(&participant)?;
guard_condition.set(true)?;
pub fn peek(&self) -> Result<bool>

Returns the current triggered state without clearing it.

Equivalent to read.

Errors

Returns an Error if the condition failed to read.

Examples
use cyclonedds::GuardCondition;

let mut guard = GuardCondition::new(&participant)?;
guard.set(true)?;
assert_eq!(guard.peek()?, true);
pub fn read(&self) -> Result<bool>

Returns the current triggered state without clearing it.

Errors

Returns an Error if the condition failed to read.

Examples
use cyclonedds::GuardCondition;

let mut guard = GuardCondition::new(&participant)?;
guard.set(true)?;
assert_eq!(guard.read()?, true);
// State is preserved after read.
assert_eq!(guard.read()?, true);
pub fn take(&mut self) -> Result<bool>

Returns the current triggered state and clears it.

Unlike read, this resets the triggered state to false after returning it.

Errors

Returns an Error if the condition failed to take.

Examples
use cyclonedds::GuardCondition;

let mut guard = GuardCondition::new(&participant)?;
guard.set(true)?;
assert_eq!(guard.take()?, true);
// State has been cleared.
assert_eq!(guard.read()?, false);