pub struct OfferedDeadlineMissedStatus {
pub total_count: u32,
pub total_count_change: i32,
pub last_instance_handle: dds_instance_handle_t,
}Expand description
Status for an offered deadline missed by a DataWriter.
Fields
total_count: u32Total cumulative count of missed deadlines.
total_count_change: i32Change in count since last read.
last_instance_handle: dds_instance_handle_tInstance handle of the last instance for which the deadline was missed.