pub struct Status(/* private fields */);Expand description
Flags for specifying the set of statuses that are of interest.
Implementations
Sourceimpl Status
impl Status
Sourcepub const InconsistentTopic: Self
pub const InconsistentTopic: Self
Another topic exists with the same name but with different
characteristics. Also see the crate::status::InconsistentTopic metadata struct.
Sourcepub const OfferedDeadlineMissed: Self
pub const OfferedDeadlineMissed: Self
The deadline that the writer has committed through its
Deadline policy was not
respected for a specific instance. Also see the crate::status::OfferedDeadlineMissed metadata struct.
Sourcepub const RequestedDeadlineMissed: Self
pub const RequestedDeadlineMissed: Self
The deadline that the reader was expecting through its
Deadline policy was not
respected for a specific instance. Also see the crate::status::RequestedDeadlineMissed metadata struct.
Sourcepub const OfferedIncompatibleQoS: Self
pub const OfferedIncompatibleQoS: Self
A QoS policy setting was incompatible with what
was requested. Also see the crate::status::OfferedIncompatibleQoS metadata struct.
Sourcepub const RequestedIncompatibleQoS: Self
pub const RequestedIncompatibleQoS: Self
A QoS policy setting was incompatible with what
is offered. Also see the crate::status::RequestedIncompatibleQoS metadata struct.
Sourcepub const SampleLost: Self
pub const SampleLost: Self
A sample has been lost (never received). Also see the crate::status::SampleLost metadata struct.
Sourcepub const SampleRejected: Self
pub const SampleRejected: Self
A received sample has been rejected. Also see the crate::status::SampleRejected metadata struct.
Sourcepub const DataOnReaders: Self
pub const DataOnReaders: Self
New information is available in some of the data readers of a subscriber.
Sourcepub const DataAvailable: Self
pub const DataAvailable: Self
New information is available in a data reader.
Sourcepub const LivelinessLost: Self
pub const LivelinessLost: Self
The liveliness that the writer has committed through its
Liveliness policy was not
respected; thus readers will consider the writer as no longer
“alive”. Also see the crate::status::LivelinessLost metadata struct.
Sourcepub const LivelinessChanged: Self
pub const LivelinessChanged: Self
The liveliness of one or more writers, that were writing instances
read through the readers has changed. Some writers have become
“alive” or “not alive”. Also see the crate::status::LivelinessChanged metadata struct.
Sourcepub const PublicationMatched: Self
pub const PublicationMatched: Self
The writer has found a reader that matches the topic and has a
compatible QoS. Also see the crate::status::PublicationMatched metadata struct.
Sourcepub const SubscriptionMatched: Self
pub const SubscriptionMatched: Self
The reader has found a writer that matches the topic and has a
compatible QoS. Also see the crate::status::SubscriptionMatched metadata struct.
Sourceimpl Status
impl Status
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Status
impl Status
Sourcepub const fn iter(&self) -> Iter<Status>
pub const fn iter(&self) -> Iter<Status>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Status>
pub const fn iter_names(&self) -> IterNames<Status>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.