This module holds the set of states of an instance.
Constants
- Alive
- The instance is alive (is not disposed and has active writers).
- Any
- The instance is in any instance state.
- Disposed
- The instance is disposed (was explicitly disposed by the writer).
- Unregistered
- The instance is unregistered (has been declared as not alive by the reader as there are no live writers writing that instance).