Module sample

Module sample 

This module holds the sample state masks that provide information on the state of a sample in the sample info from a read or take call.

Constants

Any
The sample is in any read state.
Fresh
The sample is fresh (in an unread state).
Stale
The sample is stale (has already been read by the reader).