LivelinessChanged

Struct LivelinessChanged 

pub struct LivelinessChanged {
    pub alive: Counter,
    pub not_alive: Counter,
    pub last_publication_handle: InstanceHandle,
}
Delivered to the with_liveliness_changed callback when a matched writer transitions between active and inactive.

Fields

alive: Counter

Running count of matched writers that are currently active.

not_alive: Counter

Running count of matched writers that are currently inactive.

last_publication_handle: InstanceHandle

Instance handle of the last writer whose liveliness changed.