pub struct Subscriber { /* private fields */ }Implementations
Sourceimpl Subscriber
impl Subscriber
pub fn new(participant: dds_entity_t) -> DdsResult<Self>
pub fn with_qos(participant: dds_entity_t, qos: Option<&Qos>) -> DdsResult<Self>
pub fn with_listener( participant: dds_entity_t, listener: &Listener, ) -> DdsResult<Self>
pub fn with_qos_and_listener( participant: dds_entity_t, qos: Option<&Qos>, listener: Option<&Listener>, ) -> DdsResult<Self>
pub fn create_reader<T: DdsType>( &self, topic: &Topic<T>, ) -> DdsResult<DataReader<T>>
pub fn create_reader_with_qos<T: DdsType>( &self, topic: &Topic<T>, qos: &Qos, ) -> DdsResult<DataReader<T>>
pub fn notify_readers(&self) -> DdsResult<()>
Sourcepub fn begin_coherent(&self) -> DdsResult<()>
pub fn begin_coherent(&self) -> DdsResult<()>
Begin coherent access on this subscriber.
Coherent access groups a set of data changes so that they are made available to readers as an atomic set.
Sourcepub fn end_coherent(&self) -> DdsResult<()>
pub fn end_coherent(&self) -> DdsResult<()>
End coherent access on this subscriber.
Must be paired with a prior begin_coherent call.